@@ -3,12 +3,13 @@ Main interface for cur service.
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.cur import (
+    from mypy_boto3_cur import (
         Client,
         CostandUsageReportServiceClient,
         DescribeReportDefinitionsPaginator,
-        )
+    )
 
     session = boto3.Session()
 
@@ -16,12 +17,12 @@ Usage::
     session_client: CostandUsageReportServiceClient = session.client("cur")
 
     describe_report_definitions_paginator: DescribeReportDefinitionsPaginator = client.get_paginator("describe_report_definitions")
+    ```
 """
-from mypy_boto3_cur.client import (
-    CostandUsageReportServiceClient as Client,
-    CostandUsageReportServiceClient,
-)
+from mypy_boto3_cur.client import CostandUsageReportServiceClient
 from mypy_boto3_cur.paginator import DescribeReportDefinitionsPaginator
 
+Client = CostandUsageReportServiceClient
+
 
 __all__ = ("Client", "CostandUsageReportServiceClient", "DescribeReportDefinitionsPaginator")
